.. _large_deformation-examples-index:

large_deformation
=================

.. toctree::
   :maxdepth: 2

   active_fibres.py <large_deformation-active_fibres>
   balloon.py <large_deformation-balloon>
   compare_elastic_materials.py <large_deformation-compare_elastic_materials>
   gen_yeoh_tl_up_interactive.py <large_deformation-gen_yeoh_tl_up_interactive>
   hyperelastic.py <large_deformation-hyperelastic>
   hyperelastic_tl_up_interactive.py <large_deformation-hyperelastic_tl_up_interactive>
   hyperelastic_ul.py <large_deformation-hyperelastic_ul>
   hyperelastic_ul_up.py <large_deformation-hyperelastic_ul_up>
   perfusion_tl.py <large_deformation-perfusion_tl>
